;
; 3D8L.INC
;
; 3-Dimensional 8-Level Chess 
; Copyright 1984-2000 HixoxiH Software
; v.1.0

;***************************************************
; !IMPORTANT!
;
; This file will not run/load by itself!
;
; It is designed to be included in another .ZRF
; that contains required image definitions
; and grid/dimension definitions.
;
; Each external symbol referenced below
;   is marked like this:
; 
;	;*******************
;	;EXTERNALLY DECLARED
;	;*******************
;
; The reason for doing this was to conceptually
; separate the game code from the drawing code
; (if there is such a thing in zillions.)
;
; This allows various different graphic sets to
; be defined for different screen resolutions.
;
; To play 3D8L chess just
; Load one of these rules files:
;
;	3D8L-1024x768.ZRF
;	3D8L-1280x1024.ZRF
;
;***************************************************


(
	define 3D8L-directions
	(
		directions
		;   ud ew sn
		(d   1  0  0)
		(u  -1  0  0)
		(e   0  1  0)
		(w   0 -1  0)
		(s   0  0  1) ;
		(n   0  0 -1) ;

		(de  1  1  0)
		(dw  1 -1  0)
		(ue -1  1  0)
		(uw -1 -1  0)

		(ds  1  0  1) ;
		(dn  1  0 -1) ;
		(us -1  0  1) ;
		(un -1  0 -1) ;

		(es  0  1  1) ;
		(en  0  1 -1) ;
		(ws  0 -1  1) ;
		(wn  0 -1 -1) ;

		(des  1  1  1) ;
		(den  1  1 -1) ;
		(dws  1 -1  1) ;
		(dwn  1 -1 -1) ;
		(ues -1  1  1) ;
		(uen -1  1 -1) ;
		(uws -1 -1  1) ;
		(uwn -1 -1 -1) ;
	)
)

(
	define 3D8L-Board
	(
		board

		;*******************
		;EXTERNALLY DECLARED
		;*******************
		(image-Board) ;

		(
			grid

			;*******************
			;EXTERNALLY DECLARED
			;*******************
			(Grid-Definitions)

			(3D8L-directions)
		)
		(3D8L-symmetry)
		(3D8L-zones)
	)
)

(
	define 3D8L-Pieces

	;*******************
	;EXTERNALLY DECLARED  
	;*******************
	;      (image-<PieceName>) ;

	(piece (image-GrandKnight) (name GrandKnight) (GrandKnight-text) (GrandKnight-moves) )
	(piece (image-PlainKnight) (name PlainKnight) (PlainKnight-text) (PlainKnight-moves) )
	(piece (image-GreenKnight) (name GreenKnight) (GreenKnight-text) (GreenKnight-moves) )
	(piece (image-RookBishop)  (name RookBishop)  (RookBishop-text)  (RookBishop-moves)   (attribute never-moved? true) )
	(piece (image-BishopMace)  (name BishopMace)  (BishopMace-text)  (BishopMace-moves) )
	(piece (image-RedKnight)   (name RedKnight)   (RedKnight-text)   (RedKnight-moves) )
	(piece (image-RookMace)    (name RookMace)    (RookMace-text)    (RookMace-moves) )
	(piece (image-Bishop)      (name Bishop)      (Bishop-text)      (Bishop-moves) )
	(piece (image-Queen)       (name Queen)       (Queen-text)       (Queen-moves) )
	(piece (image-Mace)        (name Mace)        (Mace-text)        (Mace-moves) )
	(piece (image-Pawn)        (name Pawn)        (Pawn-text)        (Pawn-moves) )
	(piece (image-Rook)        (name Rook)        (Rook-text)        (Rook-moves)         (attribute never-moved? true) )
	(piece (image-King)        (name King)        (King-text)        (King-moves)         (attribute never-moved? true) )
)

(
	define 3D8L-Setup
	(
		board-setup
		(
			White
			(King        5e1)
			(Queen       5d1 4e1)
			(GrandKnight 4d1)
			(RookBishop  1a1 1h1 8a1 8h1)
			(RookMace    2b1 2g1 7b1 7g1)
			(BishopMace  3c1 3f1 6c1 6f1)
			(Rook        5a1 5h1 4a1 4h1 1d1 1e1 8d1 8e1 )
			(Bishop	     5c1 5f1 4c1 4f1 3d1 3e1 6d1 6e1 )
			(Mace        2c1 2f1 3b1 3g1 6b1 6g1 7c1 7f1 )
			(RedKnight   1c1 1f1 3a1 3h1 6a1 6h1 8c1 8f1 )
			(PlainKnight 5b1 5g1 4b1 4g1 2d1 2e1 7d1 7e1 )
			(GreenKnight 1b1 1g1 2a1 2h1 7a1 7h1 8b1 8g1 )
			(
				Pawn
				1a2 1b2 1c2 1d2 1e2 1f2 1g2 1h2
				2a2 2b2 2c2 2d2 2e2 2f2 2g2 2h2
				3a2 3b2 3c2 3d2 3e2 3f2 3g2 3h2
				4a2 4b2 4c2 4d2 4e2 4f2 4g2 4h2
				5a2 5b2 5c2 5d2 5e2 5f2 5g2 5h2
				6a2 6b2 6c2 6d2 6e2 6f2 6g2 6h2
				7a2 7b2 7c2 7d2 7e2 7f2 7g2 7h2
				8a2 8b2 8c2 8d2 8e2 8f2 8g2 8h2
			)
		)

		(
			Black
			(King        5e8)
			(Queen       5d8 4e8)
			(GrandKnight 4d8)
			(RookBishop  1a8 1h8 8a8 8h8)
			(RookMace    2b8 2g8 7b8 7g8)
			(BishopMace  3c8 3f8 6c8 6f8)
			(Rook        5a8 5h8 4a8 4h8 1d8 1e8 8d8 8e8 )
			(Bishop      5c8 5f8 4c8 4f8 3d8 3e8 6d8 6e8 )
			(Mace        2c8 2f8 3b8 3g8 6b8 6g8 7c8 7f8 )
			(RedKnight   1c8 1f8 3a8 3h8 6a8 6h8 8c8 8f8 )
			(PlainKnight 5b8 5g8 4b8 4g8 2d8 2e8 7d8 7e8 )
			(GreenKnight 1b8 1g8 2a8 2h8 7a8 7h8 8b8 8g8 )
			(
				Pawn
				1a7 1b7 1c7 1d7 1e7 1f7 1g7 1h7
				2a7 2b7 2c7 2d7 2e7 2f7 2g7 2h7
				3a7 3b7 3c7 3d7 3e7 3f7 3g7 3h7
				4a7 4b7 4c7 4d7 4e7 4f7 4g7 4h7
				5a7 5b7 5c7 5d7 5e7 5f7 5g7 5h7
				6a7 6b7 6c7 6d7 6e7 6f7 6g7 6h7
				7a7 7b7 7c7 7d7 7e7 7f7 7g7 7h7
				8a7 8b7 8c7 8d7 8e7 8f7 8g7 8h7
			)
		)
	)
)

(
	define leap2
	(
		$1
		$2 
		(verify not-friend?)
		add
	)
)

(
	define king-shift
	(
		$1
		(verify not-friend?)
		(set-attribute never-moved? false)
		add
	)
)

(
	define slide
	(
		$1
		(
			while empty?
				add
				$1
		)
		(verify not-friend?)
		add
	)
)

(
	define rook-slide
	(
		$1
		(
			while empty?
				(set-attribute never-moved? false)
				add
				$1
		)
		(verify not-friend?)
		(set-attribute never-moved? false)
		add
	)
)

(
	define O-O
	(
		(verify never-moved?)
		e ; KB1
		(verify empty?)
		e ; KN1
		(verify empty?)
		cascade
		e ; KR1
		(verify (and friend? (piece? Rook) never-moved?))
		from
		back ; K1
		
		; Save expensive not-attacked?s for last
		(verify not-attacked?)
		e ; KB1
		(verify not-attacked?)
		to
		(set-attribute never-moved? false)
		; We could check if KN1 is attacked too, but this isn't
		; really necessary since Zillions doesn't allow any moves
		; into check
		e ; KN1
		(set-attribute never-moved? false)
		add
	)
)

(
	define O-Ou
	(
		(verify never-moved?)
		u ; KB1
		(verify empty?)
		u ; KN1
		(verify empty?)
		cascade
		u ; KR1
		(verify (and friend? (piece? Rook) never-moved?))
		from
		back ; K1
		
		; Save expensive not-attacked?s for last
		(verify not-attacked?)
		u ; KB1
		(verify not-attacked?)
		to
		(set-attribute never-moved? false)
		; We could check if KN1 is attacked too, but this isn't
		; really necessary since Zillions doesn't allow any moves
		; into check
		u ; KN1
		(set-attribute never-moved? false)
		add
	)
)

(
	define O-Oue
	(
		(verify never-moved?)
		ue ; KB1
		(verify empty?)
		ue ; KN1
		(verify empty?)
		cascade
		ue ; KR1
		(verify (and friend? (piece? RookBishop) never-moved?))
		from
		back ; K1
		
		; Save expensive not-attacked?s for last
		(verify not-attacked?)
		ue ; KB1
		(verify not-attacked?)
		to
		(set-attribute never-moved? false)
		; We could check if KN1 is attacked too, but this isn't
		; really necessary since Zillions doesn't allow any moves
		; into check
		ue ; KN1
		(set-attribute never-moved? false)
		add
	)
)

(
	define O-O-O
	(
		(verify never-moved?)
		w ; Q1
		(verify empty?)
		w ; QB1
		(verify empty?)
		cascade
		w ; QN1
		(verify empty?)
		w ; QR1
		(verify (and friend? (piece? Rook) never-moved?) )
		from
		back ; K1

		; Save expensive not-attacked?s for last
		(verify not-attacked?)
		w ; Q1
		(verify not-attacked?)
		to
		(set-attribute never-moved? false)
		; We could check if QB1 is attacked too, but this isn't
		; really necessary since Zillions doesn't allow any moves
		; into check
		w ; QB1
		(set-attribute never-moved? false)
		add
	)
)

(
	define O-O-Od
	(
		(verify never-moved?)
		d ; Q1
		(verify empty?)
		d ; QB1
		(verify empty?)
		cascade
		d ; QN1
		(verify empty?)
		d ; QR1
		(verify (and friend? (piece? Rook) never-moved?) )
		from
		back ; K1

		; Save expensive not-attacked?s for last
		(verify not-attacked?)
		d ; Q1
		(verify not-attacked?)
		to
		(set-attribute never-moved? false)
		; We could check if QB1 is attacked too, but this isn't
		; really necessary since Zillions doesn't allow any moves
		; into check
		d ; QB1
		(set-attribute never-moved? false)
		add
	)
)

(
	define O-O-Odw
	(
		(verify never-moved?)
		dw ; Q1
		(verify empty?)
		dw ; QB1
		(verify empty?)
		cascade
		dw ; QN1
		(verify empty?)
		dw ; QR1
		(verify (and friend? (piece? RookBishop) never-moved?) )
		from
		back ; K1

		; Save expensive not-attacked?s for last
		(verify not-attacked?)
		dw ; Q1
		(verify not-attacked?)
		to
		(set-attribute never-moved? false)
		; We could check if QB1 is attacked too, but this isn't
		; really necessary since Zillions doesn't allow any moves
		; into check
		dw ; QB1
		(set-attribute never-moved? false)
		add
	)
)

(
	define Pawn-add
	(
		if (in-zone? promotion-zone)
			(add GreenKnight RedKnight PlainKnight GrandKnight Mace Bishop Rook BishopMace RookMace RookBishop Queen)
		else
			add
	)
)

(
	define Pawn-move
	(
		n
		(verify empty?)
		(Pawn-add)
		(verify (in-zone? third-rank))
		n
		(verify empty?)
		add
	)
)

(
	define Pawn-capture
	(
		$1
		(verify enemy?)
		(Pawn-add)
	)
)

(
	define En-Passant
	(
		$1
		(verify enemy?)
		(verify last-to?)
		(verify (piece? Pawn))
		capture
		n
		to
		n
		(verify last-from?)
		add
	)
)

(
	define 3D8L-symmetry
	(
		symmetry
		Black
		(n s)
		(s n)

		(us un)
		(un us)
		(ds dn)
		(dn ds)

		(es en)
		(en es)
		(ws wn)
		(wn ws)

		(ues uen)
		(uen ues)
		(uws uwn)
		(uwn uws)
		(des den)
		(den des)
		(dws dwn)
		(dwn dws)
	)
)

(
	define Degree1
	(
		positions
		1a1 1b1 1c1 1d1 1e1 1f1 1g1 1h1
		2a1 2b1 2c1 2d1 2e1 2f1 2g1 2h1
		3a1 3b1 3c1 3d1 3e1 3f1 3g1 3h1
		4a1 4b1 4c1 4d1 4e1 4f1 4g1 4h1
		5a1 5b1 5c1 5d1 5e1 5f1 5g1 5h1
		6a1 6b1 6c1 6d1 6e1 6f1 6g1 6h1
		7a1 7b1 7c1 7d1 7e1 7f1 7g1 7h1
		8a1 8b1 8c1 8d1 8e1 8f1 8g1 8h1
	)
)


(
	define Degree3
	(
		positions
		1a3 1b3 1c3 1d3 1e3 1f3 1g3 1h3
		2a3 2b3 2c3 2d3 2e3 2f3 2g3 2h3
		3a3 3b3 3c3 3d3 3e3 3f3 3g3 3h3
		4a3 4b3 4c3 4d3 4e3 4f3 4g3 4h3
		5a3 5b3 5c3 5d3 5e3 5f3 5g3 5h3
		6a3 6b3 6c3 6d3 6e3 6f3 6g3 6h3
		7a3 7b3 7c3 7d3 7e3 7f3 7g3 7h3
		8a3 8b3 8c3 8d3 8e3 8f3 8g3 8h3
	)
)

(
	define Degree6
	(
		positions
		1a6 1b6 1c6 1d6 1e6 1f6 1g6 1h6
		2a6 2b6 2c6 2d6 2e6 2f6 2g6 2h6
		3a6 3b6 3c6 3d6 3e6 3f6 3g6 3h6
		4a6 4b6 4c6 4d6 4e6 4f6 4g6 4h6
		5a6 5b6 5c6 5d6 5e6 5f6 5g6 5h6
		6a6 6b6 6c6 6d6 6e6 6f6 6g6 6h6
		7a6 7b6 7c6 7d6 7e6 7f6 7g6 7h6
		8a6 8b6 8c6 8d6 8e6 8f6 8g6 8h6
	)
)

(
	define Degree8
	(
		positions
		1a8 1b8 1c8 1d8 1e8 1f8 1g8 1h8
		2a8 2b8 2c8 2d8 2e8 2f8 2g8 2h8
		3a8 3b8 3c8 3d8 3e8 3f8 3g8 3h8
		4a8 4b8 4c8 4d8 4e8 4f8 4g8 4h8
		5a8 5b8 5c8 5d8 5e8 5f8 5g8 5h8
		6a8 6b8 6c8 6d8 6e8 6f8 6g8 6h8
		7a8 7b8 7c8 7d8 7e8 7f8 7g8 7h8
		8a8 8b8 8c8 8d8 8e8 8f8 8g8 8h8
	)
)

(
	define WhitePromotionZone
	(
		zone
		(name promotion-zone)
		(players White)
		(Degree8)
	)

)

(
	define BlackPromotionZone
	(
		zone
		(name promotion-zone)
		(players Black)
		(Degree1)
	)
)

(
	define WhiteThirdRank
	(
		zone
		(name third-rank)
		(players White)
		(Degree3)
	)
)

(
	define BlackThirdRank
	(
		zone
		(name third-rank)
		(players Black)
		(Degree6)
	)
)

(
	define 3D8L-zones
	
	(WhitePromotionZone)
	(BlackPromotionZone)
	(WhiteThirdRank)
	(BlackThirdRank)
)

(
	define Rook-moves
	(
		moves
		(rook-slide u)
		(rook-slide d)
		(rook-slide e)
		(rook-slide w)
		(rook-slide s)
		(rook-slide n)
	)
)

(
	define Bishop-moves
	(
		moves
		(slide ue)
		(slide uw)
		(slide de)
		(slide dw)

		(slide us)
		(slide un)
		(slide ds)
		(slide dn)

		(slide es)
		(slide en)
		(slide ws)
		(slide wn)
	)
)

(
	define Mace-moves
	(
		moves
		(slide ues)
		(slide uen)
		(slide uws)
		(slide uwn)

		(slide des)
		(slide den)
		(slide dws)
		(slide dwn)
	)
)

(
	define RookBishop-moves
	(
		moves
		(rook-slide u)
		(rook-slide d)
		(rook-slide e)
		(rook-slide w)
		(rook-slide s)
		(rook-slide n)

		(slide ue)
		(slide uw)
		(slide de)
		(slide dw)

		(slide us)
		(slide un)
		(slide ds)
		(slide dn)

		(slide es)
		(slide en)
		(slide ws)
		(slide wn)
	)
)

(
	define RookMace-moves
	(
		moves
		(rook-slide u)
		(rook-slide d)
		(rook-slide e)
		(rook-slide w)
		(rook-slide s)
		(rook-slide n)

		(slide ues)
		(slide uen)
		(slide uws)
		(slide uwn)

		(slide des)
		(slide den)
		(slide dws)
		(slide dwn)
	)
)

(
	define BishopMace-moves
	(
		moves
		(slide ue)
		(slide uw)
		(slide de)
		(slide dw)

		(slide us)
		(slide un)
		(slide ds)
		(slide dn)

		(slide es)
		(slide en)
		(slide ws)
		(slide wn)

		(slide ues)
		(slide uen)
		(slide uws)
		(slide uwn)

		(slide des)
		(slide den)
		(slide dws)
		(slide dwn)
	)
)

(
	define PlainKnight-moves
	(
		moves
		;rook then bishop

		;level
		(leap2 e es)
		(leap2 e en)
		(leap2 w ws)
		(leap2 w wn)
		(leap2 es s)
		(leap2 en n)
		(leap2 ws s)
		(leap2 wn n)

		;section
		(leap2 u us)
		(leap2 u un)
		(leap2 d ds)
		(leap2 d dn)
		(leap2 un n)
		(leap2 us s)
		(leap2 dn n)
		(leap2 ds s)

		;degree
		(leap2 u ue)
		(leap2 u uw)
		(leap2 d de)
		(leap2 d dw)
		(leap2 ue e)
		(leap2 de e)
		(leap2 uw w)
		(leap2 dw w)
	)
)

(
	define RedKnight-moves
	(
		moves
		;rook then mace
		(leap2 u ues)
		(leap2 u uen)
		(leap2 u uws)
		(leap2 u uwn)
		(leap2 d des)
		(leap2 d den)
		(leap2 d dws)
		(leap2 d dwn)

		(leap2 e ues)
		(leap2 e uen)
		(leap2 e des)
		(leap2 e den)
		(leap2 w uws)
		(leap2 w uwn)
		(leap2 w dws)
		(leap2 w dwn)

		(leap2 s ues)
		(leap2 s uws)
		(leap2 s des)
		(leap2 s dws)
		(leap2 n uen)
		(leap2 n uwn)
		(leap2 n den)
		(leap2 n dwn)
	)
)

(
	define GreenKnight-moves
	(
		moves
		;bishop then mace
		(leap2 ue ues)
		(leap2 us ues)
		(leap2 es ues)

		(leap2 ue uen)
		(leap2 un uen)
		(leap2 en uen)

		(leap2 uw uws)
		(leap2 us uws)
		(leap2 ws uws)

		(leap2 uw uwn)
		(leap2 un uwn)
		(leap2 wn uwn)

		(leap2 de des)
		(leap2 ds des)
		(leap2 es des)

		(leap2 de den)
		(leap2 dn den)
		(leap2 en den)

		(leap2 dw dws)
		(leap2 ds dws)
		(leap2 ws dws)

		(leap2 dw dwn)
		(leap2 dn dwn)
		(leap2 wn dwn)
	)
)

(
	define GrandKnight-moves
	(
		moves
		;all of the knights
		;******************
		;rook then bishop
		(leap2 e es)
		(leap2 e en)
		(leap2 w ws)
		(leap2 w wn)
		(leap2 es s)
		(leap2 en n)
		(leap2 ws s)
		(leap2 wn n)

		;section
		(leap2 u us)
		(leap2 u un)
		(leap2 d ds)
		(leap2 d dn)
		(leap2 un n)
		(leap2 us s)
		(leap2 dn n)
		(leap2 ds s)

		;degree
		(leap2 u ue)
		(leap2 u uw)
		(leap2 d de)
		(leap2 d dw)
		(leap2 ue e)
		(leap2 de e)
		(leap2 uw w)
		(leap2 dw w)
		;******************
		;rook then mace
		(leap2 u ues)
		(leap2 u uen)
		(leap2 u uws)
		(leap2 u uwn)
		(leap2 d des)
		(leap2 d den)
		(leap2 d dws)
		(leap2 d dwn)

		(leap2 e ues)
		(leap2 e uen)
		(leap2 e des)
		(leap2 e den)
		(leap2 w uws)
		(leap2 w uwn)
		(leap2 w dws)
		(leap2 w dwn)

		(leap2 s ues)
		(leap2 s uws)
		(leap2 s des)
		(leap2 s dws)
		(leap2 n uen)
		(leap2 n uwn)
		(leap2 n den)
		(leap2 n dwn)
		;******************
		;bishop then mace
		(leap2 ue ues)
		(leap2 us ues)
		(leap2 es ues)

		(leap2 ue uen)
		(leap2 un uen)
		(leap2 en uen)

		(leap2 uw uws)
		(leap2 us uws)
		(leap2 ws uws)

		(leap2 uw uwn)
		(leap2 un uwn)
		(leap2 wn uwn)

		(leap2 de des)
		(leap2 ds des)
		(leap2 es des)

		(leap2 de den)
		(leap2 dn den)
		(leap2 en den)

		(leap2 dw dws)
		(leap2 ds dws)
		(leap2 ws dws)

		(leap2 dw dwn)
		(leap2 dn dwn)
		(leap2 wn dwn)
	)
)

(
	define Pawn-moves
	(
		moves
		(Pawn-capture un)
		(Pawn-capture dn)
		(Pawn-capture en)
		(Pawn-capture wn)
		(Pawn-capture uen)
		(Pawn-capture uwn)
		(Pawn-capture den)
		(Pawn-capture dwn)

		(Pawn-move)

		(En-Passant u)
		(En-Passant d)
		(En-Passant e)
		(En-Passant w)
		(En-Passant ue)
		(En-Passant de)
		(En-Passant uw)
		(En-Passant dw)
	)
)

(
	define Queen-moves
	(
		moves

		;rook
		(slide u)
		(slide d)
		(slide e)
		(slide w)
		(slide s)
		(slide n)

		;bishop
		(slide ue)
		(slide uw)
		(slide de)
		(slide dw)

		(slide us)
		(slide un)
		(slide ds)
		(slide dn)

		(slide es)
		(slide en)
		(slide ws)
		(slide wn)
		
		;mace
		(slide ues)
		(slide uen)
		(slide uws)
		(slide uwn)

		(slide des)
		(slide den)
		(slide dws)
		(slide dwn)
	)
)

(
	define King-moves
	(
		moves
		;rook
		(king-shift u)
		(king-shift d)
		(king-shift e)
		(king-shift w)
		(king-shift s)
		(king-shift n)

		;bishop
		(king-shift ue)
		(king-shift uw)
		(king-shift de)
		(king-shift dw)

		(king-shift us)
		(king-shift un)
		(king-shift ds)
		(king-shift dn)

		(king-shift es)
		(king-shift en)
		(king-shift ws)
		(king-shift wn)
		
		;mace
		(king-shift ues)
		(king-shift uen)
		(king-shift uws)
		(king-shift uwn)

		(king-shift des)
		(king-shift den)
		(king-shift dws)
		(king-shift dwn)

		(O-O)
		(O-Ou)
		(O-Oue)
		(O-O-O)
		(O-O-Od)
		(O-O-Odw)
	)
)

(
	define 3D8L-Text
	(
		description
		"
		\3D8L Chess
		\
		\Object: Checkmate the opponent's King by attacking it so it cannot escape.
		\
		\To see a description of how a piece moves right-click on it to bring up its properties dialog.
		\
		\If the board appears too large for your screen try one or more of the following:
		\1. Maximize your window.
		\2. Enable Auto-Hide for the Windows TaskBar. (so it will disappear when you're not using it) 
		\3. Drag the Zillions Toolbar to the side or turn it off.
		\4. Drag the Zillions SearchProgress to the side or turn it off.
		\5. Disable Zillions Chat (you can't relocate this)
		\6. Disable Zillions Statusbar (you can't relocate this)
		\
		\The boards for each mode were sized assuming the following settings
		\	Maximized window
		\	Taskbar set to Auto-Hide,
		\	Toolbar docked left,
		\	SearchProgress floating right,
		\	StatusBar on,
		\	Chat off
		\
		\If the board is still too large you'll either need to change screen modes or
		\	play on a lower resolution board like 3D8L-1024x768.ZRF
		"
	)
	(
		history
		"
		\TRUE 3D CHESS
		\
		\What if Chess was originally invented in 3-Dimensions and then translated into 2-Dimensions?
		\
		\3D8L is TRUE 3-Dimensional Chess.
		\
		\This game was originally produced and copyrighted in 1984 by Ray E. Bornert II.
		\It is officially recorded with the Library of Congress Copyright Office
		\	under registration numbers TX-1-561-056 and VAu-73-017.
		\
		\You can see photographs and a complete description of the game at this web-site:
		\	http://www.hixoxih.com/games/chess/3D8L.htm
		\
		\The 3D8L board and pieces and setup were not arbitrarily designed.
		\3D8L is mathematically derived from the accepted principles of 2D chess.
		\
		\Many games claim to be 3D-chess,
		\	but in reality they are either not TRUE 3D or not TRUE chess.
		\Mathematically there is only one TRUE 3D CHESS game.
		\
		\3D8L is THE TRUE 3D CHESS game.
		"
	)
	(
		strategy
		"
		\Opening: (first 100 moves)
		\
		\Develop quickly.
		\Try to control the center of the board.
		\Make enough pawn moves to bring out your Maces.
		\Be very careful about crossing beyond your 3rd degree.
		\You have 24 Knights ... use them (save your GrandKnight for later)
		\In general develop your pieces in this order:
		\  Pawns, Maces, Knights, Bishops, BishopMaces, RookMaces, RookBishops, Queens, GrandKnight, King
		\
		\Middle Game: (second 100 moves)
		\
		\Guard your Royalty - King, Queens, GrandKnight.
		\Look for ways to exchange lower valued pieces for larger valued ones.
		\Resist the temptation to exchange your Maces for enemy pawns.
		\Pawns can capture 8-ways (i.e. they fork well)
		\
		\End Game:    (third 100 moves)
		\
		\Establish a strong foothold behind the enemy pawns.
		\Fight hard on the 1st and 8th levels and the a and h sections.
		\Work your way to the center of the board.
		\Kill as many enemy pawns as you can.
		\Queen as many pawns as you can.
		\
		\Mating Material:
		\
		\It is possible to setup checkmate using only King and Queen.
		\At this time it is not known whether this can be forced.
		\However, 2-Queens can easily force checkmate.
		\
		"
	)
)

(
	define Rook-text

	(help "Rook: 6 Directions (0,0,1) (0,1,0) (1,0,0).")
	(
		description
		"
		\Rook
		\
		\The Rook is a one coordinate piece or linear piece. 
		\It moves along the lines (Columns, Files, and Ranks)
		\	in one of six directions: (0, 0, 1), (0, 1, 0), ( 1, 0, 0). 
		\
		\There are 21 possible moves for a Rook regardless of its position. 
		\The domain of a Rook on the empty board is 100%,
		\	and it can reach any point in its domain in a maximum of 3 moves. 
		\
		\The Rook is a sliding piece. 
		\Sliding pieces may not leap over intervening pieces.
		"
	)
)

(
	define Bishop-text

	(help "Bishop: 12 Directions (0,1,1) (1,0,1) (1,1,0)")
	(
		description
		"
		\Bishop
		\
		\The Bishop is a two coordinate piece or diagonal piece. 
		\It moves along the diagonals (white points or Black points)
		\	in one of twelve directions: (0, 1, 1), (1, 0, 1), (1, 1, 0). 
		\
		\There are 21 to 39 possible moves for a Bishop depending on its position. 
		\The domain of a bishop on the empty board is 50% (either the white or black points),
		\	and it can reach any point in its domain in a maximum of 3 moves. 
		\
		\The Bishop is a sliding piece. 
		\Sliding pieces may not leap over intervening pieces.
		"
	)
)

(
	define Mace-text

	(help "Mace: 8 Directions (1,1,1)")
	(
		description
		"
		\Mace
		\
		\The Mace is a three coordinate piece or a triagonal piece. 
		\It moves along triagonals
		\	(red points, green points, blue points, or yellow points)
		\	in one of eight directions: (1, 1, 1).
		\
		\There are 7 to 25 possible moves for a Mace depending on its position. 
		\The domain of a Mace on the empty board is 25%
		\	(either the red, green, blue or yellow points),
		\	and it can reach any point in its domain in a maximum of 3 moves. 
		\
		\The Mace is a sliding piece. 
		\Sliding pieces may not leap over intervening pieces.
		"
	)
)

(
	define RookBishop-text

	(help "RookBishop: moves like a Rook or Bishop.")
	(
		description
		"
		\RookBishop
		\
		\The Rookbishop is the combination of a Rook and a Bishop as the name implies. 
		\The Rookbishop moves like a Rook or Bishop. 
		\However, it cannot move like one and then the other in the same move. 
		\
		\There are 42 to 60 possible moves for a Rookbishop depending on its position. 
		\The domain of a Rookbishop on the empty board is 100%,
		\	and it can reach any point in its domain in 3 moves or less. 
		\
		\The Rookbishop is a sliding piece. 
		\Sliding pieces may not leap over intervening pieces.
		"
	)
)

(
	define RookMace-text

	(help "RookMace: moves like a Rook or Mace." )
	(
		description
		"
		\RookMace
		\
		\The Rookmace is the combination of a Rook and a Mace as the name implies. 
		\The Rookmace moves like a Rook or Mace. 
		\However, it cannot move like one and then the other in the same move. 
		\
		\There are 28 to 46 possible moves for a Rookmace depending on its position. 
		\The domain of a Rookmace on the empty board is 100%,
		\	and it can reach any point in its domain in 3 moves or less. 
		\
		\The Rookmace is a sliding piece. 
		\Sliding pieces may not leap over intervening pieces.
		"
	)
)

(
	define BishopMace-text

	(help "BishopMace: moves like a Bishop or Mace")
	(
		description
		"
		\BishopMace
		\
		\The Bishopmace is the combination of a Bishop and a Mace as the name implies. 
		\The Bishopmace moves like a Bishop or Mace. 
		\However, it cannot move like one and then the other in the same move. 
		\
		\There are 28 to 64 possible moves for a Bishopmace depending on its position. 
		\The domain of a Bishopmace on the empty board is 100%,
		\	and it can reach any point in its domain in 3 moves or less. 
		\
		\The Bishopmace is a sliding piece. 
		\Sliding pieces may not leap over intervening pieces.
		"
	)
)

(
	define PlainKnight-text

	(help "PlainKnight: 24 Directions (0,1,2) (0,2,1) (1,0,2) (2,0,1) (1,2,0) (2,1,0)")
	(
		description
		"
		\PlainKnight
		\
		\The PlainKnight is a two coordinate piece and moves in one of 24 directions:
		\	(0, 1, 2), (0, 2, 1), (1, 0, 2), (2, 0, 1), (1, 2, 0), (2, 1, 0) 
		\
		\There are 6 to 24 possible moves for a PlainKnight depending on its position. 
		\The domain of a PlainKnight on the empty board is 100% (all points),
		\	and it can reach any point in its domain in 3 to 6 moves depending on initial placement. 
		\
		\The PlainKnight is a jumping piece. 
		\Jumping pieces leap over any intervening pieces.
		"
	)
)

(
	define RedKnight-text

	(help "RedKnight: 24 Directions (1,1,2) (1,2,1) (2,1,1)")
	(
		description
		"
		\RedKnight
		\The RedKnight is a three coordinate piece and moves in one of 24 directions:
		\	(1, 1, 2), (1, 2, 1), (2, 1, 1) 
		\
		\There are 3 to 24 possible moves for a RedKnight depending on its position. 
		\The domain of a RedKnight on the empty board is 50% (either the white or black points only),
		\	and it can reach any point in its domain in 3 to 5 moves depending on initial placement.
		\
		\The RedKnight is a jumping piece. 
		\Jumping pieces leap over any intervening pieces.
		"
	)
)

(
	define GreenKnight-text

	(help "GreenKnight: 24 Directions (1,2,2) (2,1,2) (2,2,1)")
	(
		description
		"
		\GreenKnight
		\
		\The GreenKnight is a three coordinate piece and moves in one of 24 directions:
		\	(1, 2, 2), (2, 1, 2), (2, 2, 1) 
		\
		\There are 3 to 24 possible moves for a GreenKnight depending on its position. 
		\The domain of a GreenKnight on the empty board is 100% (all points),
		\	and it can reach any point in its domain in six moves or less. 
		\
		\The GreenKnight is a jumping piece. 
		\Jumping pieces leap over any intervening pieces.
		"
	)
)

(
	define GrandKnight-text

	(help "GrandKnight: moves like a PlainKnight or RedKnight or GreenKnight")
	(
		description
		"
		\GrandKnight
		\
		\The Grand Knight is a combination of a PlainKnight and a RedKnight and a GreenKnight.
		\The Grand Knight moves like a PlainKnight or RedKnight or GreenKnight.
		\However, it cannot move like one and then either or both of the other in the same move.
		\
		\There are 12 to 72 possible moves for a Grand Knight depending on its position.
		\The domain of a Grand Knight on the empty board is 100% (all points),
		\	and it can reach any point in its domain in a maximum of 3 to 5 moves depending on its position.
		\
		\The Grand Knight is a jumping piece.
		\Jumping pieces leap over any intervening pieces.
		"
	)
)

(
	define Pawn-text

	(help "Pawn: moves forward, captures diagonally and triagonally, can promote on 8th row")
	(
		description
		"
		\Pawn
		\
		\A Pawn moves like a Rook or Bishopmace with these restrictions:
		\	1. A Pawn has a distance of 1. (like the King)
		\	2. A Pawn moves forward 1 degree toward the opponent.
		\		Pawns cannot move backward or directly sideways.
		\	3. When moving directly forward on the file like a Rook the destination point must be unoccupied.
		\	4. When moving along the diagonals or triagonals like a Bishopmace,
		\		the destination point must be occupied by an enemy piece
		\		in which case the enemy piece is captured and removed from the board for the remainder of the game.
		\
		\First Move - Double Advance Option
		\	If a Pawn is moving for the very first time in the game and it is moving like a Rook,
		\	then it may slide directly forward a distance of 2 instead of just 1.
		\	Since this is Rook-style movement,
		\	both the destination point and the intervening point must be unoccupied as in restriction 3 above.
		\
		\En Passant
		\	When a Pawn makes a first move double advance,
		\	any enemy pawn that currently attacks the intervening point through which the first pawn passed
		\	gains the temporary option to capture the first pawn en passant.
		\	The option is only available for the turn immediately following the double advance.
		\
		\Promotion
		\	If a White Pawn reaches the 8th degree or a Black pawn reaches the 1st degree,
		\	it must be immediately promoted to any piece type the player chooses except a King or Pawn.
		"
	)
)

(
	define Queen-text

	(help "Queen: moves like a Rook or Bishop or Mace")
	(
		description
		"
		\Queen
		\
		\The Queen is a combination of a Rook and a Bishop and a Mace.
		\It could be called a Rookbishopmace but the name Queen imples
		\	the powers of all of the sliding pieces.
		\The Queen moves like a Rook or Bishop or Mace.
		\However, it cannot move like one and then either or both of the other in the same move.
		\
		\There are 49 to 85 possible moves for a Queen depending on its position.
		\The domain of a Queen on the empty board is 100% (all points),
		\	and it can reach any point in its domain in 3 moves or less.
		\
		\The Queen is a sliding piece.
		\Sliding pieces may not leap over intervening pieces.
		"
	)
)

(
	define King-text

	(help "King: moves to any adjacent safe point.")
	(
		description
		"
		\King
		\
		\The King is identical in movement to the Queen except that it has a distance of one (exception: Castling).
		\The domain for a King on the empty board is 100% and it can reach any point in its domain in a maximum of 7 moves.
		\A King can never move into check.
		\
		\Castling:
		\The rules for castling the King in 3D8L are the same as the 2D rules except the King can castle in six different ways instead of two.
		\A King can `castle` with a Rook/RookBishop if the following conditions are met:
		\1. All of the points between the King and the corresponding Rook/Rookbishop must be unoccupied.
		\2. Castling must be the Kings' first move of the game.
		\3. Castling must be the corresponding Rook/Rookbishops' first move of the game.
		\4. The King must not be in check.
		\5. The point(s) through which the King passes must not be in check.
		\6. The destination point where the King is castling to must not be in check.
		\
		\The notation for the six castling moves is:
		\O|O, O/O, O-O, O-O-O, O/O/O, O|O|O.
		\The O's correspond to the number of points between the King and the corresponding Rook/Rookbishop.
		\The slashes refer to the direction in which the King castled.
		\The King may castle only once for the entire game.
		"
	)
)

(
	define 3D8L-Sounds

	(win-sound "Audio\Orchestra_CF.wav")
	(loss-sound "Audio\Orchestra_FC.wav")
	(click-sound "Audio\Pickup.wav")
	(release-sound "Audio\WoodThunk.wav")
)

;======================
;THE 3D8L GAME
;======================
(
	game

	;NAME
	(title "3D8L Chess")

	;PLAYERS
	(players White Black)
	(turn-order White Black)
	(pass-turn false)

	;TEXT
	(3D8L-Text)
	
	;SOUNDS
	(3D8L-Sounds)

	;BOARD
	(3D8L-Board)

	;SETUP
	(3D8L-Setup)

	;PIECES
	(3D8L-Pieces)

	;ENDOFGAME
	(loss-condition (White Black) (checkmated King) )
)

;======================
;VARIANT
;======================

(
	variant
	(title "Mate Practice 1-Queens")
	(
		board-setup
		(
			White
			(King 5e1)
			(Queen       5d1 )
		)
		(
			Black
			(King 5e8)
		)
	)
)

(
	variant
	(title "Mate Practice 2-Queens")
	(
		board-setup
		(
			White
			(King 5e1)
			(Queen       5d1 4e1 )
		)
		(
			Black
			(King 5e8)
		)
	)
)

(
	variant
	(title "Mate Practice 8-Rooks")
	(
		board-setup
		(
			White
			(King 5e1)
			(Rook        5a1 5h1 4a1 4h1 1d1 1e1 8d1 8e1 )
		)
		(
			Black
			(King 5e8)
		)
	)
)

(
	variant
	(title "Castling practice")
	(
		board-setup
		(
			White
			(King 5e1)
			(Rook 5a1 5h1 4a1 4h1 1d1 1e1 8d1 8e1)
			(RookBishop 1a1 1h1 8a1 8h1)
		)
		(
			Black
			(King 5e8)
			(Rook 5a8 5h8 4a8 4h8 1d8 1e8 8d8 8e8)
			(RookBishop 1a8 1h8 8a8 8h8)
		)
	)
)
